@@ -7,6 +7,7 @@
 #' @param bcols For RCBD only. The number of columns in a block.
 #' @param byrow For split-plot only. Logical (default: `TRUE`). Provides a way to arrange plots within whole-plots when there are multiple possible arrangements.
 #' @param fac.sep The separator used by `fac.names`. Used to combine factorial design levels. If a vector of 2 levels is supplied, the first separates factor levels and label, and the second separates the different factors.
+#' @param buffer The type of buffer. One of edge, row, column, double row, double column, or block (coming soon).
 #' @param fac.names Allows renaming of the `A` level of factorial designs (i.e. those using [agricolae::design.ab()]) by passing (optionally named) vectors of new labels to be applied to the factors within a list. See examples and details for more information.
 #' @param plot Logical (default `TRUE`). If `TRUE`, display a plot of the generated design. A plot can always be produced later using [autoplot()].
 #' @param rotation Rotate the text output as Treatments within the plot. Allows for easier reading of long treatment labels. Takes positive and negative values being number of degrees of rotation from horizontal.
@@ -89,6 +90,7 @@ des_info <- function(design.obj,
                      byrow = TRUE,
                      fac.names = NULL,
                      fac.sep = c("", " "),
+                     buffer = NULL,
                      plot = TRUE,
                      rotation = 0,
                      size = 4,
@@ -536,6 +538,12 @@ des_info <- function(design.obj,
     info <- list(design = des)
     class(des) <- c("design", class(des))
 
+    # After creating the basic design, add buffers if requested
+    if (!is.null(buffer)) {
+        has_blocks <- any(grepl("block", tolower(names(des))))
+        des <- create_buffers(des, type = buffer, blocks = has_blocks)
+    }
+
     if(plot) {
         info$plot.des <- autoplot(des, rotation = rotation, size = size, margin = margin)
     }
